import React, { useRef } from 'react';
import { Modal, Platform, SafeAreaView, Text, TouchableOpacity } from 'react-native';
import { WebView } from 'react-native-webview';
import axios from 'axios';
export const StrapiAuthLogin = _ref => {
  let {
    isVisisble,
    lang,
    redirectUrl,
    backendUrl,
    provider,
    onCancel,
    onSuccess,
    onError,
    cancelBtnText,
    cancelBtnTextColor,
    cancelBtnBgColor
  } = _ref;
  const webView = useRef(null);
  const providerUrl = `${backendUrl}/api/connect/${provider}`;
  const patchPostMessageJsCode = `(${String(function () {
    // @ts-ignore
    var originalPostMessage = window.postMessage;

    var patchedPostMessage = function (message, targetOrigin, transfer) {
      originalPostMessage(message, targetOrigin, transfer);
    };

    patchedPostMessage.toString = function () {
      return String(Object.hasOwnProperty).replace('hasOwnProperty', 'postMessage');
    }; // @ts-ignore


    window.postMessage = patchedPostMessage;
  })})();`;

  const onNavigationStateChange = async event => {
    if (event.url.startsWith(redirectUrl)) {
      var _webView$current;

      (_webView$current = webView.current) === null || _webView$current === void 0 ? void 0 : _webView$current.stopLoading();
      let regex = /[?&]([^=#]+)=([^&#]*)/g;
      const params = Object.fromEntries([...event.url.matchAll(regex)].map(m => [m[1], m[2]]));
      const {
        access_token
      } = params;

      if (access_token) {
        try {
          const response = await axios.get(`${backendUrl}/api/auth/${provider}/callback`, {
            params: {
              access_token: `${access_token}`
            }
          });
          onSuccess(response.data);
        } catch (error) {
          if (axios.isAxiosError(error)) {
            if (error.response) onError(error.response.data);
          } else {
            if (error instanceof Error) onError(error.message);else onError('Unknown error');
          }
        }
      } else onError('No access token found');
    }
  };

  return /*#__PURE__*/React.createElement(Modal, {
    visible: isVisisble,
    animationType: "slide"
  }, /*#__PURE__*/React.createElement(SafeAreaView, {
    style: {
      height: '100%'
    }
  }, /*#__PURE__*/React.createElement(TouchableOpacity, {
    style: {
      backgroundColor: cancelBtnBgColor ?? 'transparent',
      justifyContent: 'center',
      position: 'absolute',
      bottom: '2%',
      zIndex: 1,
      alignSelf: 'center',
      padding: 12,
      borderRadius: 10
    },
    onPress: onCancel
  }, /*#__PURE__*/React.createElement(Text, {
    style: {
      textAlign: 'center',
      color: cancelBtnTextColor ?? 'rgba(180, 180, 180, 1.000)'
    }
  }, cancelBtnText ?? 'Close')), /*#__PURE__*/React.createElement(WebView, {
    userAgent: Platform.OS === 'android' ? 'Chrome/103.0.0.0 Mobile Safari/537.36' : 'AppleWebKit/605.1.15 (KHTML, like Gecko) CriOS/103.0.5060.63 Mobile/15E148 Safari/604.1',
    ref: webView,
    source: {
      uri: providerUrl,
      headers: {
        'Accept-Language': lang ?? 'en'
      }
    },
    startInLoadingState: true,
    onError: err => console.log({
      err
    }),
    onMessage: msg => console.log({
      msg
    }),
    onNavigationStateChange: onNavigationStateChange,
    injectedJavaScript: patchPostMessageJsCode
  })));
};
//# sourceMappingURL=LoginWithStrapi.js.map